# SNP query tool for answering 15 questions used for a Bayesian analysis.
#    Copyright (C) <2012>  Thomas Freina and Christian X. Weichenberger
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: DataMock.pm 49 2011-05-02 09:18:29Z dune $

use strict;
use warnings;

package Eurac::DataMock;

use Eurac::SnpDataObject;

# for testing
sub new_SnpDataObject
{
	my ( $caller, %arg ) = @_;

	my %consequencetypes = $arg{consequencetypes}
	  || { "INTRONIC" => ["ENST00000308794"], "INTERGENIC" => [ "ENST0001", "ENST0002" ] };
	my %proteinfeature_hits      = $arg{proteinfeature_hits}      || { "INTERGENIC" => ["PF0022"] };
	my %regulatoryfeature_hits   = $arg{regulatoryfeature_hits}   || {};
	my @constrainedelements_hits = $arg{constrainedelements_hits} || ["CE_???"];
	my @entrez_ids               = $arg{entrez_ids}               || [9027];
	my %gene_stable_ids          = $arg{gene_stable_ids}
	  || [ "ENSG00000144035" => ["NAT8(9027)"], "ENSG00000244120" => [], "ENSG00000163016" => [] ];

	my %debug_data = ();
	$debug_data{'ensembl_variation'}           = { 'test' => 1, 'MOCK' => 'data' };
	$debug_data{'ensembl_variationfeature'}    = { 'test' => 2, 'MOCK' => 'array' };
	$debug_data{'ensembl_constrainedelements'} = { 'test' => 3, 'MOCK' => 'hash of arrays' };

	my $data = Eurac::SnpDataObject->new(
		# digest of findings
		consequencetypes         => \%consequencetypes,
		proteinfeature_hits      => \%proteinfeature_hits,
		regulatoryfeature_hits   => \%regulatoryfeature_hits,
		constrainedelements_hits => \@constrainedelements_hits,
		entrez_ids               => \@entrez_ids,
		# TODO gene_0kb, gene_5kb
		gene_stable_ids          => \%gene_stable_ids,
		# raw data
		debug_data => \%debug_data
	);

	return $data;
}

1;
