# SNP query tool for answering 15 questions used for a Bayesian analysis.
#    Copyright (C) <2012>  Thomas Freina and Christian X. Weichenberger
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: InputParser.pm 54 2011-10-20 08:57:44Z chris $

use strict;
use warnings;

package Eurac::InputParser;

sub check_snpid
{
	my $snpid = shift;
	return ( $snpid =~ /^rs[0-9]{1,9}$/ );
}

sub is_comment
{
	my $line = shift;
	return ( $line =~ /^ *$/ || $line =~ /^#/ );
}

sub is_snp_line
{
	my $line = shift;
	return ( $line =~ /^rs[0-9]{1,9}/ );
}

sub get_snpid_from_snp_line
{
	my $snp_line = shift;
#	my @parts = split( ' ', $snp_line );
#	return $parts[0];
	my $n = ( $snp_line =~ /^(rs[0-9]{1,9})/ );
	return $1;
}

sub is_tissue_line
{
	my $line = shift;
	return ( $line =~ /^T:/ );
}

sub get_tissue_from_tissue_line
{
	my $line = shift;
	my $n = ($line =~ /^(T:[^#\s]+)/ );
	return $1;
}

sub is_phenotype_line
{
	my $line = shift;
	return ( $line =~ /^C[0-9]{1,9}/ );
}

sub get_phenotype_from_phenotype_line
{
	my $phenotype_line = shift;
	my $n = ( $phenotype_line =~ /^(C[0-9]{1,9})/ );
	return $1;
}

sub is_omim_line
{
	my $line = shift;
	my $n = ($line =~ /^(O:[0-9]+)/ );
	return $1;
}

sub get_omim_from_omim_line
{
	my $omim_line = shift;
	my $n = ( $omim_line =~ /^O:([0-9]+)/ );
	return $1;
}

1;
