# SNP query tool for answering 15 questions used for a Bayesian analysis.
#    Copyright (C) <2012>  Thomas Freina and Christian X. Weichenberger
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: Persistence.pm 49 2011-05-02 09:18:29Z dune $

use strict;
use warnings;

package Eurac::Persistence;

use Carp;

#use Storable;
use Data::Dumper;

use Eurac::DataMock;
use Eurac::SnpDataObject;

use constant DEBUG        => 1;
use constant DATA_MOCK    => 0;

# arg1: string snpid
# arg2: string data-dump directory
# return: SnpDataObject
sub load_snp_data_object
{
	my $snpid         = shift;
	my $dataDirectory = shift;

	my $dataFileName = get_snp_filename( $snpid, $dataDirectory );

	if ( -r $dataFileName )
	{
		print( "Info: ", $dataFileName, " found.\n" );
		my $ref = do($dataFileName);

		my $snpDataObject = bless( $ref, 'Eurac::SnpDataObject' );
		print( "      obj_timestamp: '", $snpDataObject->get_obj_timestamp(), "'\n" );
		print( "      obj_version:    ", $snpDataObject->get_obj_version(),   "\n" );
		print("      ignored, not current version\n") unless ( $snpDataObject->is_obj_version_current() );

		return $snpDataObject if ( $snpDataObject->is_obj_version_current() );
	}

	if (DATA_MOCK)
	{
		print( "DATA_MOCK ", $snpid, ".\n" );
		my $mockData = Eurac::DataMock::new_SnpDataObject();

		return $mockData;
	}

	return undef;
}

# arg1: string snpid
# arg2: string data-dump directory
# arg3: SnpDataObject
sub store_snp_data_object
{
	my $snpid         = shift;
	my $dataDirectory = shift;
	my $data          = shift;

	my $dataFileName = get_snp_filename( $snpid, $dataDirectory );

	print( "TRACE store_snp_data_object '", $dataFileName, "'\n" ) if DEBUG;

	open DATAFILE, ">$dataFileName" or Carp::croak( "Can\'t open file '", $dataFileName, "' for writing: $!\n" );

	#		# freeze into a binary string
	#		my $frozen = Storable::nfreeze($data);
	#
	#		# encode binary string as readable ASCII, append a newline
	#		$_ = unpack( "H*", $frozen ) . "\n"; # ??? Can\'t store CODE items at ..
	#
	#		# write to the file
	#		print DATAFILE $_ or Carp::croak( "Error writing ", $dataFileName, ": $!\n" );

	# create a new Data::Dumper object
	my $dumper = Data::Dumper->new( [$data], [qw(data)] );

	# dump the values into a variable
	my $dumpedValues = $dumper->Dump();

	# write to the file
	print( DATAFILE $dumpedValues ) or Carp::croak( "Error writing '", $dataFileName, "': $!\n" );

	# Close the data file
	close DATAFILE or Carp::croak( "Error closing '", $dataFileName, "': $!\n" );

	print( "Info: '", $dataFileName, "' written.\n" );
}

# arg1: string snpid
# arg2: string data-dump directory
# return: string: filename
sub get_snp_filename
{
	my $snpid         = shift;
	my $dataDirectory = shift;

	return $dataDirectory . "/" . "snp_" . $snpid . ".dump";
}

1;
