# SNP query tool for answering 15 questions used for a Bayesian analysis.
#    Copyright (C) <2012>  Thomas Freina and Christian X. Weichenberger
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# $Id: SnpDataObject.pm 54 2011-10-20 08:57:44Z chris $

use strict;
use warnings;

package Eurac::SnpDataObject;

use Eurac::Util;

use Carp;

use constant OBJ_VERSION => 20110812;

sub new
{
	my ( $class, %arg ) = @_;

	my $self = bless {
		_obj_version   => OBJ_VERSION,
		_obj_timestamp => Eurac::Util::get_gmtime_string(),

		# digest of findings for answers
		_consequencetypes         => $arg{consequencetypes}         || Carp::cluck("no consequencetypes"),
		_proteinfeature_hits      => $arg{proteinfeature_hits}      || Carp::cluck("no proteinfeature_hits"),
		_regulatoryfeature_hits   => $arg{regulatoryfeature_hits}   || Carp::cluck("no regulatoryfeature_hits"),
		_constrainedelements_hits => $arg{constrainedelements_hits} || Carp::cluck("no constrainedelements_hits"),
		_entrez_ids               => $arg{entrez_ids}               || Carp::cluck("no entrez_ids"),
		_gene_0kb                 => $arg{gene_0kb}                 || Carp::cluck("no gene_0kb"),
		_gene_5kb                 => $arg{gene_5kb}                 || Carp::cluck("no gene_5kb"),
		_gene_5mb                 => $arg{gene_5mb}                 || Carp::cluck("no gene_5mb"),

		# raw data from sources, for debugging, 'z' for key to be sorted to the end of dump
		_z_debug_data => $arg{debug_data},
	}, $class;

	return $self;
}

# Getters a.k.a. Accessors

sub is_obj_version_current
{
	return $_[0]->{_obj_version} == OBJ_VERSION;
}

sub get_obj_version
{
	return $_[0]->{_obj_version};
}

sub get_obj_timestamp
{
	return $_[0]->{_obj_timestamp};
}

sub get_consequencetypes
{
	return $_[0]->{_consequencetypes};
}

sub get_proteinfeature_hits
{
	return $_[0]->{_proteinfeature_hits};
}

sub get_regulatoryfeature_hits
{
	return $_[0]->{_regulatoryfeature_hits};
}

sub get_constrainedelements_hits
{
	return $_[0]->{_constrainedelements_hits};
}

sub get_entrez_ids
{
	return $_[0]->{_entrez_ids};
}

sub get_gene_0kb
{
	return $_[0]->{_gene_0kb};
}

sub get_gene_5kb
{
	return $_[0]->{_gene_5kb};
}

sub get_gene_5mb
{
	return $_[0]->{_gene_5mb};
}

sub get_debug_data
{
	return $_[0]->{_z_debug_data};
}

1;
